@@ -1,9 +1,7 @@
 var class_fixed_length_util_1_1_fixed_length_file_iterator =
 [
-    [ "constructor", "class_fixed_length_util_1_1_fixed_length_file_iterator.html#af9f645c75be376a6c267657b558acb16", null ],
-    [ "getEncoding", "class_fixed_length_util_1_1_fixed_length_file_iterator.html#a3c0db8a2221406b42314a0bdfa2f518f", null ],
     [ "getFileName", "class_fixed_length_util_1_1_fixed_length_file_iterator.html#ad081da5a8435c848744221b6684975ba", null ],
     [ "hstat", "class_fixed_length_util_1_1_fixed_length_file_iterator.html#a45649d4e0eb2f370b84c1aa93f0871a2", null ],
-    [ "stat", "class_fixed_length_util_1_1_fixed_length_file_iterator.html#a21e1c85251f58c9f1af8f72bbb0d6ce5", null ],
+    [ "stat", "class_fixed_length_util_1_1_fixed_length_file_iterator.html#aba0badb15fc80c01cf124640c59fb252", null ],
     [ "m_file_path", "class_fixed_length_util_1_1_fixed_length_file_iterator.html#a4fec5741e4a95cfc9fee69de8cab330b", null ]
 ];
\ No newline at end of file
