@@ -1,8 +1,5 @@
 var hierarchy =
 [
-    [ "ConnectionProvider::AbstractConnection", "../../ConnectionProvider/html/class_connection_provider_1_1_abstract_connection.html", [
-      [ "SmtpClient::SmtpConnection", "class_smtp_client_1_1_smtp_connection.html", null ]
-    ] ],
     [ "MailMessage::Message", "../../MailMessage/html/class_mail_message_1_1_message.html", [
       [ "SmtpClient::Message", "class_smtp_client_1_1_message.html", null ]
     ] ],
@@ -11,5 +8,7 @@ var hierarchy =
         [ "SmtpClient::Attachment", "class_smtp_client_1_1_attachment.html", null ]
       ] ]
     ] ],
-    [ "SmtpClient::SmtpClient", "class_smtp_client_1_1_smtp_client.html", null ]
+    [ "SmtpClient::SmtpClient", "class_smtp_client_1_1_smtp_client.html", null ],
+    [ "SmtpClient::SmtpConnection", "class_smtp_client_1_1_smtp_connection.html", null ],
+    [ "SmtpClient::SmtpResponseInfo", "struct_smtp_client_1_1_smtp_response_info.html", null ]
 ];
\ No newline at end of file
